@@ -3,6 +3,7 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from pulpcore.client.pulp_rpm.api.acs_rpm_api import AcsRpmApi
 from pulpcore.client.pulp_rpm.api.content_advisories_api import ContentAdvisoriesApi
 from pulpcore.client.pulp_rpm.api.content_distribution_trees_api import ContentDistributionTreesApi
 from pulpcore.client.pulp_rpm.api.content_modulemd_defaults_api import ContentModulemdDefaultsApi
@@ -19,4 +20,5 @@ from pulpcore.client.pulp_rpm.api.remotes_rpm_api import RemotesRpmApi
 from pulpcore.client.pulp_rpm.api.remotes_uln_api import RemotesUlnApi
 from pulpcore.client.pulp_rpm.api.repositories_rpm_api import RepositoriesRpmApi
 from pulpcore.client.pulp_rpm.api.repositories_rpm_versions_api import RepositoriesRpmVersionsApi
+from pulpcore.client.pulp_rpm.api.rpm_comps_api import RpmCompsApi
 from pulpcore.client.pulp_rpm.api.rpm_copy_api import RpmCopyApi
